@@ -1,3 +1,4 @@
+#![allow(deprecated)]
 // Copyright 2019 Google LLC
 //
 // Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
@@ -254,6 +255,21 @@ fn random_access_via_view_mut() {
     assert!(view.get_mut(f).is_none());
 }
 
+#[test]
+#[should_panic]
+fn simultaneous_access_must_be_non_overlapping() {
+    let mut world = World::new();
+    let a = world.spawn((1,));
+    let b = world.spawn((2,));
+    let c = world.spawn((3,));
+    let d = world.spawn((4,));
+
+    let mut query = world.query_mut::<&mut i32>();
+    let mut view = query.view();
+
+    view.get_mut_n([a, d, c, b, a]);
+}
+
 #[test]
 fn build_entity() {
     let mut world = World::new();
@@ -791,3 +807,16 @@ fn column_get_mut() {
     }
     assert_eq!(*world.get::<i32>(ent).unwrap(), 99);
 }
+
+#[test]
+fn len() {
+    let mut world = World::new();
+    let ent = world.spawn(());
+    world.spawn(());
+    world.spawn(());
+    assert_eq!(world.len(), 3);
+    world.despawn(ent).unwrap();
+    assert_eq!(world.len(), 2);
+    world.clear();
+    assert_eq!(world.len(), 0);
+}
